@@ -8,7 +8,9 @@ module Blockfrost.API.Cardano
   , module Blockfrost.API.Cardano.Assets
   , module Blockfrost.API.Cardano.Blocks
   , module Blockfrost.API.Cardano.Epochs
+  , module Blockfrost.API.Cardano.Governance
   , module Blockfrost.API.Cardano.Ledger
+  , module Blockfrost.API.Cardano.Mempool
   , module Blockfrost.API.Cardano.Metadata
   , module Blockfrost.API.Cardano.Network
   , module Blockfrost.API.Cardano.Pools
@@ -22,7 +24,9 @@ import Blockfrost.API.Cardano.Addresses
 import Blockfrost.API.Cardano.Assets
 import Blockfrost.API.Cardano.Blocks
 import Blockfrost.API.Cardano.Epochs
+import Blockfrost.API.Cardano.Governance
 import Blockfrost.API.Cardano.Ledger
+import Blockfrost.API.Cardano.Mempool
 import Blockfrost.API.Cardano.Metadata
 import Blockfrost.API.Cardano.Network
 import Blockfrost.API.Cardano.Pools
